httpd.crate.cmds


a2dissiteclj

(a2dissite vhost-conf)

Disable vhost site. vhost-conf should be the name of a conf file in sites-available

Disable vhost site. vhost-conf should be the name of a conf file in
sites-available
sourceraw docstring

a2enconfclj

(a2enconf vhost-conf)

Enable apache2 conf file. vhost-conf should be the name of a conf file in conf-available

Enable apache2 conf file. vhost-conf should be the name of a conf file in
conf-available
sourceraw docstring

a2enmodclj

(a2enmod mod)

Enable apache modules such as mod_rewrite, mode_proxy, etc

Enable apache modules such as mod_rewrite, mode_proxy, etc
sourceraw docstring

a2ensiteclj

(a2ensite vhost-conf)

Enable vhost site. vhost-conf should be the name of a conf file in sites-available

Enable vhost site. vhost-conf should be the name of a conf file in
sites-available
sourceraw docstring

apache2ctlclj

(apache2ctl cmd)

Start, stop, restart with apache2ctl command

Start, stop, restart with apache2ctl command
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries