(a2dissite vhost-conf)Disable vhost site. vhost-conf should be the name of a conf file in sites-available
Disable vhost site. vhost-conf should be the name of a conf file in sites-available
(a2enconf vhost-conf)Enable apache2 conf file. vhost-conf should be the name of a conf file in conf-available
Enable apache2 conf file. vhost-conf should be the name of a conf file in conf-available
(a2enmod mod)Enable apache modules such as mod_rewrite, mode_proxy, etc
Enable apache modules such as mod_rewrite, mode_proxy, etc
(a2ensite vhost-conf)Enable vhost site. vhost-conf should be the name of a conf file in sites-available
Enable vhost site. vhost-conf should be the name of a conf file in sites-available
(apache2ctl cmd)Start, stop, restart with apache2ctl command
Start, stop, restart with apache2ctl command
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |