(limits &
{:keys [max-clients server-limit]
:or {max-clients "150" server-limit 150}})Takes optional args and returns a vector of strings
Takes optional args and returns a vector of strings
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |